@@ -543,6 +543,79 @@ class splaytree_algorithms
       return tree_algorithms::insert_equal(header, hint, new_node, comp);
    }
 
+
+   //! <b>Requires</b>: "header" must be the header node of a tree.
+   //!   "pos" must be a valid iterator or header (end) node.
+   //!   "pos" must be an iterator pointing to the successor to "new_node"
+   //!   once inserted according to the order of already inserted nodes. This function does not
+   //!   check "pos" and this precondition must be guaranteed by the caller.
+   //!   
+   //! <b>Effects</b>: Inserts new_node into the tree before "pos".
+   //!
+   //! <b>Complexity</b>: Constant-time.
+   //! 
+   //! <b>Throws</b>: Nothing.
+   //! 
+   //! <b>Note</b>: If "pos" is not the successor of the newly inserted "new_node"
+   //! tree invariants might be broken.
+   static node_ptr insert_before
+      (node_ptr header, node_ptr pos, node_ptr new_node)
+   {
+      tree_algorithms::insert_before(header, pos, new_node);
+      splay_up(new_node, header);
+      return new_node;
+   }
+
+   //! <b>Requires</b>: "header" must be the header node of a tree.
+   //!   "new_node" must be, according to the used ordering no less than the
+   //!   greatest inserted key.
+   //!   
+   //! <b>Effects</b>: Inserts new_node into the tree before "pos".
+   //!
+   //! <b>Complexity</b>: Constant-time.
+   //! 
+   //! <b>Throws</b>: Nothing.
+   //! 
+   //! <b>Note</b>: If "new_node" is less than the greatest inserted key
+   //! tree invariants are broken. This function is slightly faster than
+   //! using "insert_before".
+   static void push_back(node_ptr header, node_ptr new_node)
+   {
+      tree_algorithms::push_back(header, new_node);
+      splay_up(new_node, header);
+   }
+
+   //! <b>Requires</b>: "header" must be the header node of a tree.
+   //!   "new_node" must be, according to the used ordering, no greater than the
+   //!   lowest inserted key.
+   //!   
+   //! <b>Effects</b>: Inserts new_node into the tree before "pos".
+   //!
+   //! <b>Complexity</b>: Constant-time.
+   //! 
+   //! <b>Throws</b>: Nothing.
+   //! 
+   //! <b>Note</b>: If "new_node" is greater than the lowest inserted key
+   //! tree invariants are broken. This function is slightly faster than
+   //! using "insert_before".
+   static void push_front(node_ptr header, node_ptr new_node)
+   {
+      tree_algorithms::push_front(header, new_node);
+      splay_up(new_node, header);
+   }
+
+   //! <b>Requires</b>: "header" must be the header node of a tree.
+   //!   NodePtrCompare is a function object that induces a strict weak
+   //!   ordering compatible with the strict weak ordering used to create the
+   //!   the tree. NodePtrCompare compares two node_ptrs.
+   //!
+   //! <b>Effects</b>: Inserts new_node into the tree before the upper bound
+   //!   according to "comp".
+   //! 
+   //! <b>Complexity</b>: Average complexity for insert element is at
+   //!   most logarithmic.
+   //! 
+   //! <b>Throws</b>: If "comp" throws.
    template<class NodePtrCompare>
    static node_ptr insert_equal_upper_bound
       (node_ptr header, node_ptr new_node, NodePtrCompare comp)
@@ -551,6 +624,18 @@ class splaytree_algorithms
       return tree_algorithms::insert_equal_upper_bound(header, new_node, comp);
    }
 
+   //! <b>Requires</b>: "header" must be the header node of a tree.
+   //!   NodePtrCompare is a function object that induces a strict weak
+   //!   ordering compatible with the strict weak ordering used to create the
+   //!   the tree. NodePtrCompare compares two node_ptrs.
+   //!
+   //! <b>Effects</b>: Inserts new_node into the tree before the lower bound
+   //!   according to "comp".
+   //! 
+   //! <b>Complexity</b>: Average complexity for insert element is at
+   //!   most logarithmic.
+   //! 
+   //! <b>Throws</b>: If "comp" throws.
    template<class NodePtrCompare>
    static node_ptr insert_equal_lower_bound
       (node_ptr header, node_ptr new_node, NodePtrCompare comp)
@@ -605,9 +690,8 @@ class splaytree_algorithms
 //      if( data_->parent == t )
 //         data_->parent = find_leftmost();
          //posibility 1
-      if(splay && NodeTraits::get_left(z) != 0 ){
-         node_ptr l = prev_node(z);
-         splay_up(l, header);
+      if(splay && NodeTraits::get_left(z)){
+         splay_up(prev_node(z), header);
       }
       /*
       //possibility 2
@@ -644,8 +728,8 @@ class splaytree_algorithms
       if( n == t ) return;
       
       for( ;; ){
-         node_ptr p = NodeTraits::get_parent(n);
-         node_ptr g = NodeTraits::get_parent(p);
+         node_ptr p(NodeTraits::get_parent(n));
+         node_ptr g(NodeTraits::get_parent(p));
 
          if( p == t )   break;
          
@@ -688,9 +772,8 @@ class splaytree_algorithms
       if(!NodeTraits::get_left(t) && !NodeTraits::get_right(t))
          return t;
       //Backup leftmost/rightmost
-      node_ptr leftmost    = NodeTraits::get_left(header);
-      node_ptr rightmost   = NodeTraits::get_right(header);
-
+      node_ptr leftmost (NodeTraits::get_left(header));
+      node_ptr rightmost(NodeTraits::get_right(header));
       {
          detail::splaydown_rollback<NodeTraits> rollback(&t, header, leftmost, rightmost);
          node_ptr null = header;
