@@ -1,4 +1,4 @@
-//  Copyright (c) 2001-2009 Hartmut Kaiser
+//  Copyright (c) 2001-2010 Hartmut Kaiser
 // 
 //  Distributed under the Boost Software License, Version 1.0. (See accompanying 
 //  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -86,7 +86,7 @@ namespace boost { namespace spirit { namespace lex
                         boost::detail::iterator_traits<Iterator>::value_type 
                     token_type;
 
-                    token_type &t = *first;
+                    token_type const& t = *first;
                     if (token_is_valid(t) && t.state() == first.get_state()) {
                     // any of the token definitions matched
                         spirit::traits::assign_to(t, attr);
