@@ -35,16 +35,6 @@ user_data
         }
     };
 
-#if BOOST_WORKAROUND(__CODEGEARC__, BOOST_TESTED_AT(0x610))
-struct tag_test_1 {};
-struct tag_test_2 {};
-struct tag_test_3 {};
-struct tag_test_4 {};
-struct tag_test_5 {};
-struct tag_test_6 {};
-struct tag_user_data {};
-#endif
-
 typedef boost::error_info<struct tag_test_1,int> test_1;
 typedef boost::error_info<struct tag_test_2,unsigned int> test_2;
 typedef boost::error_info<struct tag_test_3,float> test_3;
@@ -83,6 +73,23 @@ basic_test()
         }
     catch(
     test_exception & x )
+        {
+        ++*boost::get_error_info<test_1>(x);
+        ++*boost::get_error_info<test_2>(x);
+        ++*boost::get_error_info<test_3>(x);
+        BOOST_TEST(*boost::get_error_info<test_1>(x)==2);
+        BOOST_TEST(*boost::get_error_info<test_2>(x)==3u);
+        BOOST_TEST(*boost::get_error_info<test_3>(x)==4.14159f);
+        BOOST_TEST(!boost::get_error_info<test_4>(x));
+        }
+    try
+        {
+        test_exception x;
+        x << test_1(1) << test_2(2u) << test_3(3.14159f);
+        throw x;
+        }
+    catch(
+    test_exception const & x )
         {
         BOOST_TEST(*boost::get_error_info<test_1>(x)==1);
         BOOST_TEST(*boost::get_error_info<test_2>(x)==2u);
@@ -301,7 +308,6 @@ test_lifetime()
     try
         {
         throw test_exception() << test_7(user_data(count));
-        BOOST_TEST(false);
         }
     catch(
     boost::exception & x )
@@ -317,6 +323,28 @@ test_lifetime()
     BOOST_TEST(!count);
     }
 
+bool
+is_const( int const * )
+    {
+    return true;
+    }
+
+bool
+is_const( int * )
+    {
+    return false;
+    }
+
+void
+test_const()
+    {
+    test_exception e;
+    boost::exception const & c(e);
+    boost::exception & m(e);
+    BOOST_TEST(is_const(boost::get_error_info<test_1>(c)));
+    BOOST_TEST(!is_const(boost::get_error_info<test_1>(m)));
+    }
+
 int
 main()
     {
@@ -327,5 +355,6 @@ main()
     test_catch_add_info();
     test_add_tuple();
     test_lifetime();
+    test_const();
     return boost::report_errors();
     }
