@@ -7,8 +7,8 @@
 #
 # Paths to tools come first, change these to match your system:
 #
-math2svg='C:\download\open\SVGMath-0.3.1\math2svg.py'
-python=/cygdrive/c/Python25/python.exe
+math2svg='d:\download\open\SVGMath-0.3.1\math2svg.py'
+python=/cygdrive/c/Python26/python.exe
 inkscape=/cygdrive/c/progra~1/Inkscape/inkscape
 # Image DPI:
 dpi=120
@@ -29,3 +29,4 @@ done
 
 
 
+
