@@ -3,7 +3,10 @@
 //  Boost Software License, Version 1.0.  (See accompanying file
 //  LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 //
-#define BOOST_MATH_TR1_SOURCE
+#  include <pch.hpp>
+#ifndef BOOST_MATH_TR1_SOURCE
+#  define BOOST_MATH_TR1_SOURCE
+#endif
 #include <boost/math/tr1.hpp>
 #include <boost/math/special_functions/ellint_3.hpp>
 #include "c_policy.hpp"
@@ -12,3 +15,5 @@ extern "C" long double BOOST_MATH_TR1_DECL ellint_3l BOOST_PREVENT_MACRO_SUBSTIT
 {
    return c_policies::ellint_3 BOOST_PREVENT_MACRO_SUBSTITUTION(k, nu, phi);
 }
+
+
