@@ -7,7 +7,10 @@
 //  Authors: Matthias Troyer
 
 #define BOOST_ARCHIVE_SOURCE
-#include <boost/archive/impl/archive_pointer_iserializer.ipp>
+
+#include <boost/archive/detail/archive_serializer_map.hpp>
+#include <boost/archive/impl/archive_serializer_map.ipp>
+
 #include <boost/mpi/skeleton_and_content.hpp>
 
 #include <boost/archive/binary_iarchive.hpp>
@@ -19,8 +22,8 @@ namespace boost { namespace archive {
 // explicitly instantiate all required templates
 
 template class basic_binary_iarchive<mpi::packed_skeleton_iarchive> ;
-template class detail::archive_pointer_iserializer<mpi::packed_skeleton_iarchive> ;
-template class detail::archive_pointer_iserializer<
+template class detail::archive_serializer_map<mpi::packed_skeleton_iarchive> ;
+template class detail::archive_serializer_map<
   mpi::detail::forward_skeleton_iarchive<
     boost::mpi::packed_skeleton_iarchive, boost::mpi::packed_iarchive> > ;
 //template class binary_iarchive_impl<packed_skeleton_iarchive> ;
