@@ -2,7 +2,7 @@
     Boost.Wave: A Standard compliant C++ preprocessor library
     http://www.boost.org/
 
-    Copyright (c) 2001-2009 Hartmut Kaiser. Distributed under the Boost
+    Copyright (c) 2001-2010 Hartmut Kaiser. Distributed under the Boost
     Software License, Version 1.0. (See accompanying file
     LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -13,10 +13,12 @@
     license reproduced at the end of this file.
 =============================================================================*/
 
-// Tests error reporting: ill-formed group in a source file. 
+// Tests translation limits.
 
-// 17.5: Errorneous #endif without #if in an included file.
-#endif
+#undef NEST
+#define NEST 4
+
+#include "t_5_035_05.hpp"
 
 /*-
  * Copyright (c) 1998, 2002-2005 Kiyoshi Matsui <kmatsui@t3.rim.or.jp>
